@@ -28,6 +28,7 @@ import (
 	"github.com/openshift/elasticsearch-operator/internal/manifests/cronjob"
 	"github.com/openshift/elasticsearch-operator/internal/manifests/pod"
 	"github.com/openshift/elasticsearch-operator/internal/manifests/rbac"
+	"github.com/openshift/elasticsearch-operator/internal/metrics"
 	esapi "github.com/openshift/elasticsearch-operator/internal/types/elasticsearch"
 	"github.com/openshift/elasticsearch-operator/internal/utils/comparators"
 )
@@ -231,6 +232,7 @@ func (imr *IndexManagementRequest) removeCronJobsForMappings(mappings []apis.Ind
 	expected := sets.NewString()
 	for _, mapping := range mappings {
 		expected.Insert(fmt.Sprintf("%s-im-%s", imr.cluster.Name, mapping.Name))
+		expected.Insert(fmt.Sprintf("%s-im-prune-%s", imr.cluster.Name, mapping.Name))
 	}
 
 	cronList, err := cronjob.List(context.TODO(), imr.client, imr.cluster.Namespace, imLabels)
@@ -337,15 +339,38 @@ func (imr *IndexManagementRequest) reconcileIndexManagementCronjob(policy apis.I
 	}
 
 	if policy.Phases.Delete != nil {
+		var (
+			namespaceCount       = 0
+			namespaceSpecs       = make(map[string]string)
+			namespaceSpecsString = ""
+		)
+
+		if policy.Phases.Delete.Namespaces != nil {
+			for _, spec := range policy.Phases.Delete.Namespaces {
+				namespaceSpecs[spec.Namespace] = string(spec.MinAge)
+			}
+			namespaceCount = len(policy.Phases.Delete.Namespaces)
+			namespaceSpecsJSON, _ := json.Marshal(namespaceSpecs)
+			namespaceSpecsString = string(namespaceSpecsJSON)
+		}
+
 		minAgeMillis, err := calculateMillisForTimeUnit(policy.Phases.Delete.MinAge)
 		if err != nil {
 			return err
 		}
+
 		envvars = append(envvars,
 			corev1.EnvVar{Name: "MIN_AGE", Value: strconv.FormatUint(minAgeMillis, 10)},
+			corev1.EnvVar{Name: "NAMESPACE_SPECS", Value: namespaceSpecsString},
 		)
+
+		metrics.SetIndexRetentionDocumentAge(true, mapping.Name, minAgeMillis/millisPerSecond)
+		metrics.SetIndexRetentionDeleteNamespaceMetrics(mapping.Name, namespaceCount)
 	} else {
 		log.V(1).Info("Skipping curation management for policymapping; delete phase not defined", "policymapping", mapping.Name)
+
+		metrics.SetIndexRetentionDocumentAge(true, mapping.Name, 0)
+		metrics.SetIndexRetentionDeleteNamespaceMetrics(mapping.Name, 0)
 	}
 
 	if policy.Phases.Hot != nil {
@@ -358,10 +383,37 @@ func (imr *IndexManagementRequest) reconcileIndexManagementCronjob(policy apis.I
 			corev1.EnvVar{Name: "PAYLOAD", Value: base64.StdEncoding.EncodeToString(payload)},
 		)
 
+		if policy.Phases.Hot.Actions.Rollover != nil {
+			maxAgeMillis, _ := calculateMillisForTimeUnit(policy.Phases.Hot.Actions.Rollover.MaxAge)
+			metrics.SetIndexRetentionDocumentAge(false, mapping.Name, maxAgeMillis/millisPerSecond)
+		}
 	} else {
 		log.V(1).Info("Skipping rollover management for policymapping; hot phase not defined", "policymapping", mapping.Name)
+
+		metrics.SetIndexRetentionDocumentAge(false, mapping.Name, 0)
 	}
 
+	// prune-namespaces cron job
+	if policy.Phases.Delete != nil && policy.Phases.Delete.Namespaces != nil {
+		schedule, err := crontabScheduleFor(policy.Phases.Delete.PruneNamespacesInterval)
+		if err != nil {
+			return kverrors.Wrap(err, "failed to reconcile prune cronjob", "policymapping", mapping.Name, "namespaceSpec", policy.Phases.Delete.Namespaces)
+		}
+		name := fmt.Sprintf("%s-im-prune-%s", imr.cluster.Name, mapping.Name)
+		script := "./prune-namespaces"
+		desired := newCronJob(imr.cluster.Name, imr.cluster.Namespace, name, schedule, script, imr.cluster.Spec.Spec.NodeSelector, imr.cluster.Spec.Spec.Tolerations, envvars, suspend)
+
+		imr.cluster.AddOwnerRefTo(desired)
+
+		err = cronjob.CreateOrUpdate(context.TODO(), imr.client, desired, areCronJobsSame, cronjob.Mutate)
+		if err != nil {
+			return kverrors.Wrap(err, "failed to create or update cronjob",
+				"cluster", desired.Name,
+				"namespace", desired.Namespace,
+			)
+		}
+	}
+	// delete & rollover cron job
 	schedule, err := crontabScheduleFor(policy.PollInterval)
 	if err != nil {
 		return kverrors.Wrap(err, "failed to reconcile rollover cronjob", "policymapping", mapping.Name)
@@ -399,7 +451,7 @@ func formatCmd(policy apis.IndexManagementPolicySpec) string {
 }
 
 func areCronJobsSame(lhs, rhs *batch.CronJob) bool {
-	if len(lhs.Spec.JobTemplate.Spec.Template.Spec.Containers) != len(lhs.Spec.JobTemplate.Spec.Template.Spec.Containers) {
+	if len(lhs.Spec.JobTemplate.Spec.Template.Spec.Containers) != len(rhs.Spec.JobTemplate.Spec.Template.Spec.Containers) {
 		return false
 	}
 	if !comparators.AreStringMapsSame(lhs.Spec.JobTemplate.Spec.Template.Spec.NodeSelector, rhs.Spec.JobTemplate.Spec.Template.Spec.NodeSelector) {
